Multiple Choice Questions
--------------------------
.. mchoice:: webEx_MC1
    :practice: T
    :answer_a: Paragraph
    :answer_b: Tree
    :answer_c: Stem and Leaf
    :answer_d: Nested
    :correct: b
    :feedback_a: Paragraph structure is a writing style, not a coding outline.
    :feedback_b: An XML document can be depicted as a tree structure where there is a top element, and other tags are drawn as children of their parent elements.
    :feedback_c: Stem and Leaf is a plot used to display quantitative data, where each data value is split into a "leaf" (usually the last digit) and a "stem" (the other digits).
    :feedback_d: While the structure of XML is inherently nested, it follows a tree structure.

    An XML document can be depicted using what kind of structure?

.. mchoice:: webEx_MC2
    :practice: T
    :answer_a: CSS
    :answer_b: Python
    :answer_c: JavaScript
    :answer_d: HTML
    :correct: d
    :feedback_a: CSS is a language that describes the style of an HTML document.
    :feedback_b: Python is a programming language, but is quite different than XML.
    :feedback_c: JavaScript is the programming language of HTML and the Web. It looks pretty different from XML.
    :feedback_d: HTML is the standard markup language for Web pages. It is very similar to XML, though XML is more structured.

    What language is XML most similar to?

.. mchoice:: webEx_MC3
    :practice: T
    :answer_a: find
    :answer_b: findtag
    :answer_c: match
    :answer_d: xmltag
    :correct: a
    :feedback_a: The find function searches through the XML tree, retrieving the element that matches the tag.
    :feedback_b: This is not a real function.
    :feedback_c: match is an attribute that can be used to associate a template with an XML element.
    :feedback_d: This is not a real function.

    Which function searches through the XML tree and retrieves the element that matches the specified tag.

.. mchoice:: webEx_MC4
    :practice: T
    :answer_a: True
    :answer_b: False
    :correct: b
    :feedback_a: Try again!
    :feedback_b: An XML tree usually has multiple nodes.

    True or False? An XML tree can only have one node.

.. mchoice:: webEx_MC5
    :practice: T
    :answer_a: JavaScript arrays
    :answer_b: JavaScript
    :answer_c: XML nodes
    :answer_d: Python lists and dictionaries
    :correct: d
    :feedback_a: The JSON format was inspired by the object and array format used in the JavaScript language, but was influenced and looks nearly identical to Python lists and dictionaries.
    :feedback_b: JSON is text, written with JavaScript object notation, but the format is nearly identical to one of the other options.
    :feedback_c: JSON and XML are used for similar purposes, but JSON is written with simpler structures.
    :feedback_d: Python’s syntax for dictionaries and lists influenced the syntax of JSON. So the format of JSON is nearly identical to a combination of Python lists and dictionaries

    The JSON format is most similar to which of the following?

.. mchoice:: webEx_MC6
    :practice: T
    :answer_a: True
    :answer_b: False
    :correct: a
    :feedback_a: JSON is a very natural format to use, as it maps directly to some combination of dictionaries and lists.
    :feedback_b: Try again!

    True or False? JSON maps directly to dictionaries and lists.

.. mchoice:: webEx_MC7
    :practice: T
    :answer_a: XML
    :answer_b: JSON
    :correct: a
    :feedback_a: JSON is simpler and more directly maps to native data structures we already have in programming languages, the parsing and data extraction code is usually simpler and more direct when using JSON.
    :feedback_b: XML is more self descriptive than JSON, but does not have the simpler and more direct mapping that JSON has.

    There is an industry trend away from _______.

.. mchoice:: webEx_MC8
    :practice: T
    :answer_a: XML
    :answer_b: JSON
    :correct: b
    :feedback_a: Try again!
    :feedback_b: JSON is constructed by nesting dictionaries and lists as needed.

    Which format is constructed by nesting dictionaries and lists as needed.

.. mchoice:: webEx_MC9_new
    :practice: T
    :multiple_answers:
    :answer_a: Combination Code
    :answer_b: API Key
    :answer_c: OAuth
    :answer_d: A physical key
    :correct: b,c
    :feedback_a: Try again! Some sort of password may be used, but not one that is intended for a combination lock.
    :feedback_b: An API Key is used by vendors to know who is using their services and how much each user is using.
    :feedback_c: OAuth is used to send cryptographically signed messages using shared keys and secrets.
    :feedback_d: There are no physical keys here!

    Which of the following are used for security surrounding API usage?
